/**
 *
 */

// Colors
var UBUNTU_ORANGE_COLOR = "#DD4814"; //Ubuntu orange
var LIGHT_AUBERGINE_COLOR = "#77216F"; //Light aubergine
var MID_AUBERGINE_COLOR = "#5E2750"; //Mid aubergine
var DARK_AUBERGINE_COLOR = "#2C001E"; //Dark aubergine
var WARM_GREY_COLOR = "#AEA79F"; //Warm grey
var COOL_GREY_COLOR = "#333333"; //Cool grey
// --

//var DEFAULT_ORIENTATION = "portrait";
var DEFAULT_ORIENTATION = "auto";
var DEFAULT_FONT_PIXEL_SIZE = 30;
var DEFAULT_MARGIN = 10;
var TRANSPARENT = "#00000000";
var SHADOW_COLOR = "#77000000";
var SHADOW_OFFSET = 3;

var DEFAULT_BACKGROUND_COLOR = UBUNTU_ORANGE_COLOR;

var DEFAULT_FOREGROUND_COLOR = "white";

//var DEFAULT_DIALOG_BACKGROUND_COLOR = UBUNTU_ORANGE_COLOR;
//var DEFAULT_DIALOG_BACKGROUND_COLOR = LIGHT_AUBERGINE_COLOR;
var DEFAULT_DIALOG_BACKGROUND_COLOR = COOL_GREY_COLOR;
var DEFAULT_DIALOG_FOREGROUND_COLOR = "white";

var MENU_BACKGROUND_COLOR = UBUNTU_ORANGE_COLOR;

var DEFAULT_TIP_BACKGROUND_COLOR = "red";
var DEFAULT_TIP_FOREGROUND_COLOR = "white";
var DEFAULT_TEXT_COLOR = DEFAULT_FOREGROUND_COLOR;

var DEFAULT_FOLDER = "file:///home/user/MyDocs";

var SYSTEM_BAR_HEIGHT = 70;
var TOP_BAR_HEIGHT = 10;
var TEXT_MARGIN = 25;

// images

var ICON_UP = "images/upload.png";
var ICON_DOWN = "images/download.png";

// End of file.
